# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.workflow.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_workflow_dot_v1_dot_api__pb2
from ai.stigmer.agentic.workflow.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_workflow_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ai/stigmer/agentic/workflow/v1/command.proto\x12\x1e\x61i.stigmer.agentic.workflow.v1\x1a(ai/stigmer/agentic/workflow/v1/api.proto\x1a\'ai/stigmer/agentic/workflow/v1/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xd5\x04\n\x19WorkflowCommandController\x12[\n\x05\x61pply\x12(.ai.stigmer.agentic.workflow.v1.Workflow\x1a(.ai.stigmer.agentic.workflow.v1.Workflow\x12\xaa\x01\n\x06\x63reate\x12(.ai.stigmer.agentic.workflow.v1.Workflow\x1a(.ai.stigmer.agentic.workflow.v1.Workflow\"L\xc2\xb8\x18H\x08\x11\x10\x1e\"\x0cmetadata.org*4unauthorized to create workflow in this organization\x12\x94\x01\n\x06update\x12(.ai.stigmer.agentic.workflow.v1.Workflow\x1a(.ai.stigmer.agentic.workflow.v1.Workflow\"6\xc2\xb8\x18\x32\x08\x04\x10\x32\"\x0bmetadata.id*\x1funauthorized to update workflow\x12\x90\x01\n\x06\x64\x65lete\x12*.ai.stigmer.agentic.workflow.v1.WorkflowId\x1a(.ai.stigmer.agentic.workflow.v1.Workflow\"0\xc2\xb8\x18,\x08\x02\x10\x32\"\x05value*\x1funauthorized to delete workflow\x1a\x04\xa0\xff+2B\xcf\x01\n\"com.ai.stigmer.agentic.workflow.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SAW\xaa\x02\x1e\x41i.Stigmer.Agentic.Workflow.V1\xca\x02\x1e\x41i\\Stigmer\\Agentic\\Workflow\\V1\xe2\x02*Ai\\Stigmer\\Agentic\\Workflow\\V1\\GPBMetadata\xea\x02\"Ai::Stigmer::Agentic::Workflow::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.ai.stigmer.agentic.workflow.v1B\014CommandProtoP\001\242\002\004ASAW\252\002\036Ai.Stigmer.Agentic.Workflow.V1\312\002\036Ai\\Stigmer\\Agentic\\Workflow\\V1\342\002*Ai\\Stigmer\\Agentic\\Workflow\\V1\\GPBMetadata\352\002\"Ai::Stigmer::Agentic::Workflow::V1'
  _globals['_WORKFLOWCOMMANDCONTROLLER']._loaded_options = None
  _globals['_WORKFLOWCOMMANDCONTROLLER']._serialized_options = b'\240\377+2'
  _globals['_WORKFLOWCOMMANDCONTROLLER'].methods_by_name['create']._loaded_options = None
  _globals['_WORKFLOWCOMMANDCONTROLLER'].methods_by_name['create']._serialized_options = b'\302\270\030H\010\021\020\036\"\014metadata.org*4unauthorized to create workflow in this organization'
  _globals['_WORKFLOWCOMMANDCONTROLLER'].methods_by_name['update']._loaded_options = None
  _globals['_WORKFLOWCOMMANDCONTROLLER'].methods_by_name['update']._serialized_options = b'\302\270\0302\010\004\0202\"\013metadata.id*\037unauthorized to update workflow'
  _globals['_WORKFLOWCOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_WORKFLOWCOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\030,\010\002\0202\"\005value*\037unauthorized to delete workflow'
  _globals['_WORKFLOWCOMMANDCONTROLLER']._serialized_start=289
  _globals['_WORKFLOWCOMMANDCONTROLLER']._serialized_end=886
# @@protoc_insertion_point(module_scope)
